==> file?get=wackowiki-6.0.38.zip: wackowiki-6.0.38/src/lib/README.md <==
WackoWiki external libraries
============================
This directory contains a copy of the 3rd party libraries used by WackoWiki

The version and status of each is summarized below:

## PHP libraries

| directory			| project			| version	| status |
| ----------------- | ----------------- | --------- | --------- |
| bad_behavior		| Bad Behavior		| 2.2.24	| patched: various, see repo |
| captcha			| freeCap			| 1.4.6		| patched: various, see repo |
| hashids			| Hashids			| 4.1.0		| unpatched |
| htmlsax3			| HTMLSAX3			| 3.0.0		| patched: various, see repo |
| php-diff			| php-diff			| 2.4.0		| patched, see subdir |
| phpmailer			| PHPMailer			| 6.10.0	| unpatched |
| phpthumb			| PhpThumb			| 2.1		| patched: various, see repo |
| safehtml			| SafeHTML			| 1.3.12	| patched: various, see repo |
| simplepie			| SimplePie			| 1.8.1		| unpatched |
| svg-sanitizer		| svg-sanitizer		| 0.20		| patched: various, see repo |
| text-hl			| Text_Highlighter	| 0.8.0		| patched: various, see repo |

## JavaScript libraries

| directory			| project			| version	| status |
| ----------------- | ----------------- | --------- | --------- |
| js				| clipboard.js		| 2.0.11	| unpatched |
| js				| WikiEdit			| 3.23		| unpatched |

Upstream projects
-----------------
- bad_behavior		- https://bad-behavior.ioerror.us/
- clipboard.js		- https://github.com/zenorocha/clipboard.js
- freecap			- https://wackowiki.org/doc/Dev/Components/Lib/Captcha
- hashids			- https://hashids.org/php/
- htmlsax3			- https://pear.php.net/package/XML_HTMLSax3/
- php-diff			- https://github.com/JBlond/php-diff
- phpmailer			- https://github.com/PHPMailer/PHPMailer
- phpthumb			- https://github.com/PHPThumb/PHPThumb
- safehtml			- https://wackowiki.org/doc/Dev/Projects/SafeHTML
- simplepie			- https://github.com/simplepie/simplepie
- svg-sanitizer		- https://github.com/darylldoyle/svg-sanitizer
- text_highlighter	- https://pear.php.net/package/Text_Highlighter/
- wikiedit			- https://wackowiki.org/doc/Dev/Projects/WikiEdit

==> file?get=wackowiki-6.1.29.zip: wackowiki-6.1.29/src/lib/README.md <==
WackoWiki external libraries
============================
This directory contains a copy of the 3rd party libraries used by WackoWiki

The version and status of each is summarized below:

## PHP libraries

| directory			| project			| version	| status |
| ----------------- | ----------------- | --------- | --------- |
| bad_behaviour		| Bad Behaviour		| 2.2.25	| unpatched |
| captcha			| freeCap			| 1.4.7		| unpatched |
| hashids			| Hashids			| 5.0.2		| unpatched |
| htmlsax3			| HTMLSAX3			| 3.0.0		| patched: various, see repo |
| php-diff			| php-diff			| 2.4.0		| patched, see subdir |
| phpmailer			| PHPMailer			| 6.10.0	| unpatched |
| phpthumb			| PhpThumb			| 2.3.2		| unpatched |
| safehtml			| SafeHTML			| 1.3.12	| patched: various, see repo |
| simplepie			| SimplePie			| 1.8.1		| unpatched |
| svg-sanitizer		| svg-sanitizer		| 0.22		| patched: various, see repo |
| text-hl			| Text_Highlighter	| 0.8.0		| patched: various, see repo |

## JavaScript libraries

| directory			| project			| version	| status |
| ----------------- | ----------------- | --------- | --------- |
| js				| clipboard.js		| 2.0.11	| unpatched |
| js				| WikiEdit			| 3.23		| unpatched |

Upstream projects
-----------------
- bad_behaviour		- https://github.com/Bad-Behaviour/badbehaviour
- clipboard.js		- https://github.com/zenorocha/clipboard.js
- freecap			- https://wackowiki.org/doc/Dev/Components/Lib/Captcha
- hashids			- https://hashids.org/php/
- htmlsax3			- https://pear.php.net/package/XML_HTMLSax3/
- php-diff			- https://github.com/JBlond/php-diff
- phpmailer			- https://github.com/PHPMailer/PHPMailer
- phpthumb			- https://github.com/PHPThumb/PHPThumb
- safehtml			- https://wackowiki.org/doc/Dev/Projects/SafeHTML
- simplepie			- https://github.com/simplepie/simplepie
- svg-sanitizer		- https://github.com/darylldoyle/svg-sanitizer
- text_highlighter	- https://pear.php.net/package/Text_Highlighter/
- wikiedit			- https://wackowiki.org/doc/Dev/Projects/WikiEdit
